==> signer-1.101.0-sources.jar: software/amazon/awscdk/services/signer/CfnSigningProfileProps.java <==
package software.amazon.awscdk.services.signer;

/**
 * Properties for defining a `AWS::Signer::SigningProfile`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:07:19.629Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.signer.$Module.class, fqn = "@aws-cdk/aws-signer.CfnSigningProfileProps")
@software.amazon.jsii.Jsii.Proxy(CfnSigningProfileProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnSigningProfileProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Signer::SigningProfile.PlatformId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getPlatformId();

    /**
     * `AWS::Signer::SigningProfile.SignatureValidityPeriod`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getSignatureValidityPeriod() {
        return null;
    }

    /**
     * `AWS::Signer::SigningProfile.Tags`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnSigningProfileProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnSigningProfileProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnSigningProfileProps> {
        private java.lang.String platformId;
        private java.lang.Object signatureValidityPeriod;
        private java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Sets the value of {@link CfnSigningProfileProps#getPlatformId}
         * @param platformId `AWS::Signer::SigningProfile.PlatformId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder platformId(java.lang.String platformId) {
            this.platformId = platformId;
            return this;
        }

        /**
         * Sets the value of {@link CfnSigningProfileProps#getSignatureValidityPeriod}
         * @param signatureValidityPeriod `AWS::Signer::SigningProfile.SignatureValidityPeriod`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder signatureValidityPeriod(software.amazon.awscdk.services.signer.CfnSigningProfile.SignatureValidityPeriodProperty signatureValidityPeriod) {
            this.signatureValidityPeriod = signatureValidityPeriod;
            return this;
        }

        /**
         * Sets the value of {@link CfnSigningProfileProps#getSignatureValidityPeriod}
         * @param signatureValidityPeriod `AWS::Signer::SigningProfile.SignatureValidityPeriod`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder signatureValidityPeriod(software.amazon.awscdk.core.IResolvable signatureValidityPeriod) {
            this.signatureValidityPeriod = signatureValidityPeriod;
            return this;
        }

        /**
         * Sets the value of {@link CfnSigningProfileProps#getTags}
         * @param tags `AWS::Signer::SigningProfile.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSigningProfileProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnSigningProfileProps build() {
            return new Jsii$Proxy(platformId, signatureValidityPeriod, tags);
        }
    }

    /**
     * An implementation for {@link CfnSigningProfileProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnSigningProfileProps {
        private final java.lang.String platformId;
        private final java.lang.Object signatureValidityPeriod;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.platformId = software.amazon.jsii.Kernel.get(this, "platformId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.signatureValidityPeriod = software.amazon.jsii.Kernel.get(this, "signatureValidityPeriod", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.lang.String platformId, final java.lang.Object signatureValidityPeriod, final java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.platformId = java.util.Objects.requireNonNull(platformId, "platformId is required");
            this.signatureValidityPeriod = signatureValidityPeriod;
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)tags;
        }

        @Override
        public final java.lang.String getPlatformId() {
            return this.platformId;
        }

        @Override
        public final java.lang.Object getSignatureValidityPeriod() {
            return this.signatureValidityPeriod;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("platformId", om.valueToTree(this.getPlatformId()));
            if (this.getSignatureValidityPeriod() != null) {
                data.set("signatureValidityPeriod", om.valueToTree(this.getSignatureValidityPeriod()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-signer.CfnSigningProfileProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnSigningProfileProps.Jsii$Proxy that = (CfnSigningProfileProps.Jsii$Proxy) o;

            if (!platformId.equals(that.platformId)) return false;
            if (this.signatureValidityPeriod != null ? !this.signatureValidityPeriod.equals(that.signatureValidityPeriod) : that.signatureValidityPeriod != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.platformId.hashCode();
            result = 31 * result + (this.signatureValidityPeriod != null ? this.signatureValidityPeriod.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}

==> signer-1.174.0-sources.jar: software/amazon/awscdk/services/signer/CfnSigningProfileProps.java <==
package software.amazon.awscdk.services.signer;

/**
 * Properties for defining a `CfnSigningProfile`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.signer.*;
 * CfnSigningProfileProps cfnSigningProfileProps = CfnSigningProfileProps.builder()
 *         .platformId("platformId")
 *         // the properties below are optional
 *         .signatureValidityPeriod(SignatureValidityPeriodProperty.builder()
 *                 .type("type")
 *                 .value(123)
 *                 .build())
 *         .tags(List.of(CfnTag.builder()
 *                 .key("key")
 *                 .value("value")
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-21T22:31:00.800Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.signer.$Module.class, fqn = "@aws-cdk/aws-signer.CfnSigningProfileProps")
@software.amazon.jsii.Jsii.Proxy(CfnSigningProfileProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnSigningProfileProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ID of a platform that is available for use by a signing profile.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getPlatformId();

    /**
     * The validity period override for any signature generated using this signing profile.
     * <p>
     * If unspecified, the default is 135 months.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getSignatureValidityPeriod() {
        return null;
    }

    /**
     * A list of tags associated with the signing profile.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnSigningProfileProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnSigningProfileProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnSigningProfileProps> {
        java.lang.String platformId;
        java.lang.Object signatureValidityPeriod;
        java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Sets the value of {@link CfnSigningProfileProps#getPlatformId}
         * @param platformId The ID of a platform that is available for use by a signing profile. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder platformId(java.lang.String platformId) {
            this.platformId = platformId;
            return this;
        }

        /**
         * Sets the value of {@link CfnSigningProfileProps#getSignatureValidityPeriod}
         * @param signatureValidityPeriod The validity period override for any signature generated using this signing profile.
         *                                If unspecified, the default is 135 months.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder signatureValidityPeriod(software.amazon.awscdk.services.signer.CfnSigningProfile.SignatureValidityPeriodProperty signatureValidityPeriod) {
            this.signatureValidityPeriod = signatureValidityPeriod;
            return this;
        }

        /**
         * Sets the value of {@link CfnSigningProfileProps#getSignatureValidityPeriod}
         * @param signatureValidityPeriod The validity period override for any signature generated using this signing profile.
         *                                If unspecified, the default is 135 months.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder signatureValidityPeriod(software.amazon.awscdk.core.IResolvable signatureValidityPeriod) {
            this.signatureValidityPeriod = signatureValidityPeriod;
            return this;
        }

        /**
         * Sets the value of {@link CfnSigningProfileProps#getTags}
         * @param tags A list of tags associated with the signing profile.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSigningProfileProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnSigningProfileProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnSigningProfileProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnSigningProfileProps {
        private final java.lang.String platformId;
        private final java.lang.Object signatureValidityPeriod;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.platformId = software.amazon.jsii.Kernel.get(this, "platformId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.signatureValidityPeriod = software.amazon.jsii.Kernel.get(this, "signatureValidityPeriod", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.platformId = java.util.Objects.requireNonNull(builder.platformId, "platformId is required");
            this.signatureValidityPeriod = builder.signatureValidityPeriod;
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)builder.tags;
        }

        @Override
        public final java.lang.String getPlatformId() {
            return this.platformId;
        }

        @Override
        public final java.lang.Object getSignatureValidityPeriod() {
            return this.signatureValidityPeriod;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("platformId", om.valueToTree(this.getPlatformId()));
            if (this.getSignatureValidityPeriod() != null) {
                data.set("signatureValidityPeriod", om.valueToTree(this.getSignatureValidityPeriod()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-signer.CfnSigningProfileProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnSigningProfileProps.Jsii$Proxy that = (CfnSigningProfileProps.Jsii$Proxy) o;

            if (!platformId.equals(that.platformId)) return false;
            if (this.signatureValidityPeriod != null ? !this.signatureValidityPeriod.equals(that.signatureValidityPeriod) : that.signatureValidityPeriod != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.platformId.hashCode();
            result = 31 * result + (this.signatureValidityPeriod != null ? this.signatureValidityPeriod.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}
